@@ -5,7 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.10
+;; Package-Version: 1.11
+;; Package-Revision: 55b5bbeb1eb9
 ;; Package-Requires: ((emacs "29.1") (org "9.6") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -920,7 +921,7 @@ whole buffer; otherwise, for the line at point."
           (while (< (point) (point-max))
             (when-let ((org-not-done-regexp (get-text-property (point) 'org-not-done-regexp))
                        (re (get-text-property (point) 'org-todo-regexp))
-                       (re (concat " " re " "))
+                       (re (concat "[: ]" re " "))
                        ((re-search-forward re (pos-eol) 'noerror)))
               (org-modern--todo))
             (goto-char (min (1+ (pos-eol)) (point-max)))))
